# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: operator.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import table_meta_pb2 as table__meta__pb2
from . import table_common_pb2 as table__common__pb2
from . import data_type_pb2 as data__type__pb2
from . import expression_pb2 as expression__pb2
from . import file_format_type_pb2 as file__format__type__pb2
from . import file_meta_data_pb2 as file__meta__data__pb2
from . import input_split_pb2 as input__split__pb2
from . import file_system_pb2 as file__system__pb2
from . import virtual_value_info_pb2 as virtual__value__info__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0eoperator.proto\x12\x08\x63z.proto\x1a\x10table_meta.proto\x1a\x12table_common.proto\x1a\x0f\x64\x61ta_type.proto\x1a\x10\x65xpression.proto\x1a\x16\x66ile_format_type.proto\x1a\x14\x66ile_meta_data.proto\x1a\x11input_split.proto\x1a\x11\x66ile_system.proto\x1a\x18virtual_value_info.proto\"2\n\rColumnMapping\x12\x10\n\x08outputId\x18\x01 \x01(\x04\x12\x0f\n\x07inputId\x18\x02 \x01(\x04\"\x8c\x0b\n\x08Operator\x12\n\n\x02id\x18\x01 \x01(\t\x12\x10\n\x08inputIds\x18\x02 \x03(\t\x12\"\n\x06schema\x18\x03 \x01(\x0b\x32\x12.cz.proto.DataType\x12/\n\x0e\x63olumnMappings\x18\x04 \x03(\x0b\x32\x17.cz.proto.ColumnMapping\x12\x11\n\tsignature\x18\x05 \x01(\x04\x12)\n\ntable_scan\x18\n \x01(\x0b\x32\x13.cz.proto.TableScanH\x00\x12)\n\ntable_sink\x18\x0b \x01(\x0b\x32\x13.cz.proto.TableSinkH\x00\x12\x1e\n\x04\x63\x61lc\x18\x0c \x01(\x0b\x32\x0e.cz.proto.CalcH\x00\x12)\n\nmerge_sort\x18\r \x01(\x0b\x32\x13.cz.proto.MergeSortH\x00\x12/\n\rshuffle_write\x18\x0e \x01(\x0b\x32\x16.cz.proto.ShuffleWriteH\x00\x12-\n\x0cshuffle_read\x18\x0f \x01(\x0b\x32\x15.cz.proto.ShuffleReadH\x00\x12\"\n\x06values\x18\x10 \x01(\x0b\x32\x10.cz.proto.ValuesH\x00\x12+\n\x08hash_agg\x18\x11 \x01(\x0b\x32\x17.cz.proto.HashAggregateH\x00\x12/\n\nsorted_agg\x18\x12 \x01(\x0b\x32\x19.cz.proto.SortedAggregateH\x00\x12-\n\nmerge_join\x18\x13 \x01(\x0b\x32\x17.cz.proto.SortMergeJoinH\x00\x12\'\n\thash_join\x18\x14 \x01(\x0b\x32\x12.cz.proto.HashJoinH\x00\x12)\n\nlocal_sort\x18\x15 \x01(\x0b\x32\x13.cz.proto.LocalSortH\x00\x12\'\n\tunion_all\x18\x16 \x01(\x0b\x32\x12.cz.proto.UnionAllH\x00\x12\"\n\x06\x62uffer\x18\x17 \x01(\x0b\x32\x10.cz.proto.BufferH\x00\x12\"\n\x06window\x18\x18 \x01(\x0b\x32\x10.cz.proto.WindowH\x00\x12\"\n\x06\x65xpand\x18\x19 \x01(\x0b\x32\x10.cz.proto.ExpandH\x00\x12-\n\x0clateral_view\x18\x1a \x01(\x0b\x32\x15.cz.proto.LateralViewH\x00\x12&\n\x08grouping\x18\x1b \x01(\x0b\x32\x12.cz.proto.GroupingH\x00\x12%\n\x04join\x18\x32 \x01(\x0b\x32\x15.cz.proto.LogicalJoinH\x00\x12/\n\taggregate\x18\x33 \x01(\x0b\x32\x1a.cz.proto.LogicalAggregateH\x00\x12-\n\x0clogical_calc\x18\x34 \x01(\x0b\x32\x15.cz.proto.LogicalCalcH\x00\x12-\n\x0clogical_sort\x18\x35 \x01(\x0b\x32\x15.cz.proto.LogicalSortH\x00\x12-\n\x0cset_operator\x18\x36 \x01(\x0b\x32\x15.cz.proto.SetOperatorH\x00\x12-\n\tagg_phase\x18\x37 \x01(\x0b\x32\x18.cz.proto.AggregatePhaseH\x00\x12 \n\x05spool\x18\x38 \x01(\x0b\x32\x0f.cz.proto.SpoolH\x00\x12>\n\x15partial_window_filter\x18\x39 \x01(\x0b\x32\x1d.cz.proto.PartialWindowFilterH\x00\x12\'\n\ttree_join\x18: \x01(\x0b\x32\x12.cz.proto.TreeJoinH\x00\x12\x30\n\x0etree_join_leaf\x18; \x01(\x0b\x32\x16.cz.proto.TreeJoinLeafH\x00\x12\x31\n\x0elocal_exchange\x18< \x01(\x0b\x32\x17.cz.proto.LocalExchangeH\x00\x42\x04\n\x02op\"\xd2\x02\n\rAggregateCall\x12,\n\x08\x66unction\x18\x01 \x01(\x0b\x32\x1a.cz.proto.ScalarExpression\x12\x10\n\x08\x64istinct\x18\x02 \x01(\x08\x12!\n\x05stage\x18\x03 \x01(\x0e\x32\x12.cz.proto.AggStage\x12%\n\x06orders\x18\x04 \x03(\x0b\x32\x15.cz.proto.OrderByDesc\x12#\n\x06\x66ilter\x18\x05 \x01(\x0b\x32\x13.cz.proto.Reference\x12\x15\n\routput_fields\x18\x06 \x03(\x04\x12(\n\x0cinitial_Type\x18\n \x01(\x0b\x32\x12.cz.proto.DataType\x12(\n\x0cpartial_Type\x18\x0b \x01(\x0b\x32\x12.cz.proto.DataType\x12\'\n\x0boutput_Type\x18\x0c \x01(\x0b\x32\x12.cz.proto.DataType\"g\n\x10LogicalAggregate\x12!\n\x04keys\x18\x01 \x03(\x0b\x32\x13.cz.proto.Reference\x12\x30\n\x0f\x61ggregate_calls\x18\x02 \x03(\x0b\x32\x17.cz.proto.AggregateCall\"a\n\rHashAggregate\x12-\n\taggregate\x18\x01 \x01(\x0b\x32\x1a.cz.proto.LogicalAggregate\x12!\n\x05stage\x18\x02 \x01(\x0e\x32\x12.cz.proto.AggStage\"\x8a\x01\n\x0fSortedAggregate\x12-\n\taggregate\x18\x01 \x01(\x0b\x32\x1a.cz.proto.LogicalAggregate\x12!\n\x05stage\x18\x02 \x01(\x0e\x32\x12.cz.proto.AggStage\x12%\n\x06orders\x18\x03 \x03(\x0b\x32\x15.cz.proto.OrderByDesc\"b\n\x0e\x41ggregatePhase\x12-\n\taggregate\x18\x01 \x01(\x0b\x32\x1a.cz.proto.LogicalAggregate\x12!\n\x05stage\x18\x02 \x01(\x0e\x32\x12.cz.proto.AggStage\"\xaa\x01\n\x11\x44ynamicFilterInfo\x12)\n\x04type\x18\x01 \x01(\x0e\x32\x1b.cz.proto.DynamicFilterType\x12\x10\n\x08\x63onsumer\x18\x02 \x01(\x08\x12\x13\n\x0bselectivity\x18\x03 \x01(\x01\x12\r\n\x05probe\x18\x04 \x01(\r\x12\x18\n\x10partition_filter\x18\x05 \x01(\x08\x12\x1a\n\x12table_scan_parents\x18\x06 \x01(\r\")\n\x0cJoinHintInfo\x12\x19\n\x11hintBroadcastSide\x18\x01 \x01(\x05\"6\n\x08TreeJoin\x12*\n\x0eroot_operators\x18\x01 \x03(\x0b\x32\x12.cz.proto.Operator\";\n\x0cTreeJoinLeaf\x12\x13\n\x0binput_index\x18\x01 \x01(\x05\x12\x16\n\x0ehint_broadcast\x18\x02 \x01(\x08\"\xd7\x01\n\x0bLogicalJoin\x12 \n\x04type\x18\x01 \x01(\x0e\x32\x12.cz.proto.JoinType\x12-\n\tcondition\x18\x02 \x01(\x0b\x32\x1a.cz.proto.ScalarExpression\x12\x18\n\x10input_references\x18\x03 \x03(\x04\x12\x33\n\x0e\x64ynamic_filter\x18\x04 \x01(\x0b\x32\x1b.cz.proto.DynamicFilterInfo\x12(\n\x08hintInfo\x18\x05 \x01(\x0b\x32\x16.cz.proto.JoinHintInfo\"\x8a\x01\n\rSortMergeJoin\x12#\n\x04join\x18\x01 \x01(\x0b\x32\x15.cz.proto.LogicalJoin\x12)\n\nlhs_orders\x18\x02 \x03(\x0b\x32\x15.cz.proto.OrderByDesc\x12)\n\nrhs_orders\x18\x03 \x03(\x0b\x32\x15.cz.proto.OrderByDesc\"]\n\x08HashJoin\x12#\n\x04join\x18\x01 \x01(\x0b\x32\x15.cz.proto.LogicalJoin\x12\x19\n\x11probe_operator_id\x18\x02 \x01(\t\x12\x11\n\tbroadcast\x18\x03 \x01(\x08\"/\n\x06Timing\x12\x11\n\tcpu_nanos\x18\x01 \x01(\x04\x12\x12\n\nwall_nanos\x18\x02 \x01(\x04\"\xe3\n\n\rOperatorStats\x12\x13\n\x0boperator_id\x18\x01 \x01(\t\x12\x11\n\trow_count\x18\x02 \x01(\x04\x12 \n\x06timing\x18\x03 \x01(\x0b\x32\x10.cz.proto.Timing\x12\x34\n\x10table_scan_stats\x18\x04 \x01(\x0b\x32\x18.cz.proto.TableScanStatsH\x00\x12\x34\n\x10table_sink_stats\x18\x05 \x01(\x0b\x32\x18.cz.proto.TableSinkStatsH\x00\x12)\n\ncalc_stats\x18\x06 \x01(\x0b\x32\x13.cz.proto.CalcStatsH\x00\x12\x32\n\x0fhash_join_stats\x18\x07 \x01(\x0b\x32\x17.cz.proto.HashJoinStatsH\x00\x12\x34\n\x10merge_join_stats\x18\x08 \x01(\x0b\x32\x18.cz.proto.MergeJoinStatsH\x00\x12<\n\x14hash_aggregate_stats\x18\t \x01(\x0b\x32\x1c.cz.proto.HashAggregateStatsH\x00\x12>\n\x15merge_aggregate_stats\x18\n \x01(\x0b\x32\x1d.cz.proto.MergeAggregateStatsH\x00\x12\x34\n\x10local_sort_stats\x18\x0b \x01(\x0b\x32\x18.cz.proto.LocalSortStatsH\x00\x12\x34\n\x10merge_sort_stats\x18\x0c \x01(\x0b\x32\x18.cz.proto.MergeSortStatsH\x00\x12-\n\x0cvalues_stats\x18\r \x01(\x0b\x32\x15.cz.proto.ValuesStatsH\x00\x12:\n\x13\x65xchange_sink_stats\x18\x0e \x01(\x0b\x32\x1b.cz.proto.ExchangeSinkStatsH\x00\x12>\n\x15\x65xchange_source_stats\x18\x0f \x01(\x0b\x32\x1d.cz.proto.ExchangeSourceStatsH\x00\x12\x32\n\x0funion_all_stats\x18\x10 \x01(\x0b\x32\x17.cz.proto.UnionAllStatsH\x00\x12-\n\x0c\x62uffer_stats\x18\x11 \x01(\x0b\x32\x15.cz.proto.BufferStatsH\x00\x12-\n\x0cwindow_stats\x18\x12 \x01(\x0b\x32\x15.cz.proto.WindowStatsH\x00\x12-\n\x0c\x65xpand_stats\x18\x13 \x01(\x0b\x32\x15.cz.proto.ExpandStatsH\x00\x12\x38\n\x12lateral_view_stats\x18\x14 \x01(\x0b\x32\x1a.cz.proto.LateralViewStatsH\x00\x12<\n\x14partial_window_stats\x18\x15 \x01(\x0b\x32\x1c.cz.proto.PartialWindowStatsH\x00\x12%\n\x0binit_timing\x18\x64 \x01(\x0b\x32\x10.cz.proto.Timing\x12\x13\n\x0b\x62\x61tch_count\x18\x65 \x01(\x04\x12\x13\n\x0bpeak_memory\x18\x66 \x01(\x04\x12\x18\n\x10start_time_nanos\x18g \x01(\x04\x12\x16\n\x0e\x65nd_time_nanos\x18h \x01(\x04\x12\x17\n\x0f\x62\x61tch_signature\x18i \x01(\x04\x12\x14\n\x0c\x65xec_node_id\x18j \x01(\t\x12\x13\n\x0bpipeline_id\x18k \x01(\x04\x12\x17\n\x0f\x64river_sequence\x18l \x01(\x04\x12\x1a\n\x12\x62lock_timing_nanos\x18m \x01(\x04\x12\x1b\n\x12\x65xtra_stats_binary\x18\xfe\x01 \x01(\x0c\x12\x14\n\x0b\x65xtra_stats\x18\xff\x01 \x01(\tB\n\n\x08op_stats\"U\n\x0bOrderByDesc\x12&\n\treference\x18\x01 \x01(\x0b\x32\x13.cz.proto.Reference\x12\x1e\n\x05order\x18\x02 \x01(\x0e\x32\x0f.cz.proto.Order\"L\n\tMergeSort\x12%\n\x06orders\x18\x01 \x03(\x0b\x32\x15.cz.proto.OrderByDesc\x12\x18\n\x10input_references\x18\x02 \x03(\x04\"$\n\x08UnionAll\x12\x18\n\x10input_references\x18\x01 \x03(\x04\"\x18\n\x06\x42uffer\x12\x0e\n\x06shared\x18\x01 \x01(\x08\"v\n\x13PartialWindowFilter\x12,\n\x08\x66unction\x18\x01 \x01(\x0b\x32\x1a.cz.proto.ScalarExpression\x12\"\n\x04spec\x18\x02 \x01(\x0b\x32\x14.cz.proto.WindowSpec\x12\r\n\x05limit\x18\x03 \x01(\x04\"I\n\x06Window\x12%\n\x06groups\x18\x01 \x03(\x0b\x32\x15.cz.proto.WindowGroup\x12\x18\n\x10input_references\x18\x02 \x03(\x04\"Z\n\x0bWindowGroup\x12\'\n\tfunctions\x18\x01 \x03(\x0b\x32\x14.cz.proto.WindowCall\x12\"\n\x04spec\x18\x02 \x01(\x0b\x32\x14.cz.proto.WindowSpec\"v\n\nWindowCall\x12,\n\x08\x66unction\x18\x01 \x01(\x0b\x32\x1a.cz.proto.ScalarExpression\x12\x10\n\x08\x64istinct\x18\x02 \x01(\x08\x12(\n\x0cpartial_type\x18\x03 \x01(\x0b\x32\x12.cz.proto.DataType\"\x9e\x02\n\nWindowSpec\x12!\n\x04keys\x18\x01 \x03(\x0b\x32\x13.cz.proto.Reference\x12%\n\x06orders\x18\x02 \x03(\x0b\x32\x15.cz.proto.OrderByDesc\x12\x38\n\rboundary_type\x18\x03 \x01(\x0e\x32!.cz.proto.WindowSpec.BoundaryType\x12-\n\x0blower_bound\x18\x04 \x01(\x0b\x32\x18.cz.proto.WindowBoundary\x12-\n\x0bupper_bound\x18\x05 \x01(\x0b\x32\x18.cz.proto.WindowBoundary\".\n\x0c\x42oundaryType\x12\x08\n\x04ROWS\x10\x00\x12\t\n\x05RANGE\x10\x01\x12\t\n\x05GROUP\x10\x02\"Z\n\x0eWindowBoundary\x12\x16\n\tpreceding\x18\x01 \x01(\x08H\x00\x88\x01\x01\x12\"\n\x06offset\x18\x02 \x01(\x0b\x32\x12.cz.proto.ConstantB\x0c\n\n_preceding\"W\n\x0bLateralView\x12.\n\tfunctions\x18\x01 \x03(\x0b\x32\x1b.cz.proto.TableFunctionCall\x12\x18\n\x10input_references\x18\x02 \x03(\x04\"e\n\x11TableFunctionCall\x12,\n\x08\x66unction\x18\x01 \x01(\x0b\x32\x1a.cz.proto.ScalarExpression\x12\r\n\x05outer\x18\x02 \x01(\x08\x12\x13\n\x0bused_fields\x18\x03 \x03(\x04\"\x19\n\x05Spool\x12\x10\n\x08spool_id\x18\x01 \x01(\x04\"\xfb\x01\n\x04\x43\x61lc\x12/\n\x0b\x65xpressions\x18\x01 \x03(\x0b\x32\x1a.cz.proto.ScalarExpression\x12\x13\n\tno_filter\x18\x02 \x01(\x08H\x00\x12\x10\n\x06\x66ilter\x18\x03 \x01(\x04H\x00\x12\x10\n\x08projects\x18\x04 \x03(\x04\x12 \n\x04lazy\x18\x05 \x03(\x0e\x32\x12.cz.proto.LazyEval\x12.\n!partial_window_filter_selectivity\x18\x06 \x01(\x01H\x01\x88\x01\x01\x42\x11\n\x0foptional_filterB$\n\"_partial_window_filter_selectivity\"\xc0\x01\n\x0bLogicalCalc\x12-\n\tcondition\x18\x01 \x01(\x0b\x32\x1a.cz.proto.ScalarExpression\x12,\n\x08projects\x18\x02 \x03(\x0b\x32\x1a.cz.proto.ScalarExpression\x12.\n!partial_window_filter_selectivity\x18\x03 \x01(\x01H\x00\x88\x01\x01\x42$\n\"_partial_window_filter_selectivity\"9\n\x06\x45xpand\x12/\n\x0b\x65xpressions\x18\x01 \x03(\x0b\x32\x1a.cz.proto.ScalarExpression\"3\n\x0eGroupingKeySet\x12!\n\x04keys\x18\x01 \x03(\x0b\x32\x13.cz.proto.Reference\"\xea\x01\n\x08Grouping\x12!\n\x04keys\x18\x01 \x03(\x0b\x32\x13.cz.proto.Reference\x12)\n\x07keySets\x18\x02 \x03(\x0b\x32\x18.cz.proto.GroupingKeySet\x12\x30\n\x0f\x61ggregate_calls\x18\x03 \x03(\x0b\x32\x17.cz.proto.AggregateCall\x12\x1e\n\x16grouping_id_start_from\x18\x04 \x01(\x04\x12#\n\x16grouping_id_col_offset\x18\x05 \x01(\x04H\x00\x88\x01\x01\x42\x19\n\x17_grouping_id_col_offset\"\x0b\n\tCalcStats\"\x8e\x01\n\x0eHashTableStats\x12\x13\n\x0bnum_buckets\x18\x01 \x01(\x04\x12\x10\n\x08num_keys\x18\x02 \x01(\x04\x12\x12\n\nnum_resize\x18\x03 \x01(\x04\x12\x14\n\x0cnum_accesses\x18\x04 \x01(\x04\x12\x16\n\x0enum_collisions\x18\x05 \x01(\x04\x12\x13\n\x0bused_memory\x18\x06 \x01(\x04\"\xed\x04\n\rHashJoinStats\x12&\n\x0c\x62uild_timing\x18\x01 \x01(\x0b\x32\x10.cz.proto.Timing\x12-\n\x13\x66inish_build_timing\x18\x02 \x01(\x0b\x32\x10.cz.proto.Timing\x12&\n\x0cprobe_timing\x18\x03 \x01(\x0b\x32\x10.cz.proto.Timing\x12+\n\x11post_probe_timing\x18\x04 \x01(\x0b\x32\x10.cz.proto.Timing\x12*\n\x08ht_stats\x18\x05 \x01(\x0b\x32\x18.cz.proto.HashTableStats\x12\x16\n\x0enum_build_rows\x18\x06 \x01(\x04\x12\x1f\n\x17num_distinct_build_rows\x18\x07 \x01(\x04\x12\x1c\n\x14max_equal_build_rows\x18\x08 \x01(\x04\x12/\n\x11\x62uild_spill_stats\x18\t \x01(\x0b\x32\x14.cz.proto.SpillStats\x12/\n\x11probe_spill_stats\x18\n \x01(\x0b\x32\x14.cz.proto.SpillStats\x12.\n\x14probe_find_ht_timing\x18\x0b \x01(\x0b\x32\x10.cz.proto.Timing\x12-\n\x13probe_output_timing\x18\x0c \x01(\x0b\x32\x10.cz.proto.Timing\x12\x34\n\x1aprobe_eval_conjunct_timing\x18\r \x01(\x0b\x32\x10.cz.proto.Timing\x12\x36\n\x1cprobe_output_conjunct_timing\x18\x0e \x01(\x0b\x32\x10.cz.proto.Timing\"\x10\n\x0eMergeJoinStats\"\xe7\x02\n\x12HashAggregateStats\x12.\n\x14\x61ssign_states_timing\x18\x01 \x01(\x0b\x32\x10.cz.proto.Timing\x12.\n\x14update_states_timing\x18\x02 \x01(\x0b\x32\x10.cz.proto.Timing\x12\'\n\routput_timing\x18\x03 \x01(\x0b\x32\x10.cz.proto.Timing\x12*\n\x08ht_stats\x18\x04 \x01(\x0b\x32\x18.cz.proto.HashTableStats\x12\x1a\n\x12states_used_memory\x18\x05 \x01(\x04\x12\x19\n\x11pass_through_rows\x18\x06 \x01(\x04\x12/\n\x11input_spill_stats\x18\x07 \x01(\x0b\x32\x14.cz.proto.SpillStats\x12\x34\n\x16\x61ggregated_spill_stats\x18\x08 \x01(\x0b\x32\x14.cz.proto.SpillStats\"\x9e\x01\n\x13MergeAggregateStats\x12.\n\x14\x61ssign_states_timing\x18\x01 \x01(\x0b\x32\x10.cz.proto.Timing\x12.\n\x14update_states_timing\x18\x02 \x01(\x0b\x32\x10.cz.proto.Timing\x12\'\n\routput_timing\x18\x03 \x01(\x0b\x32\x10.cz.proto.Timing\"\xff\x02\n\x0eLocalSortStats\x12)\n\x0bspill_stats\x18\x01 \x01(\x0b\x32\x14.cz.proto.SpillStats\x12-\n\x13generate_run_timing\x18\x02 \x01(\x0b\x32\x10.cz.proto.Timing\x12*\n\x10merge_run_timing\x18\x03 \x01(\x0b\x32\x10.cz.proto.Timing\x12+\n\x11init_merge_timing\x18\x04 \x01(\x0b\x32\x10.cz.proto.Timing\x12\x31\n\x17\x61\x63\x63umulate_block_timing\x18\x05 \x01(\x0b\x32\x10.cz.proto.Timing\x12)\n\x0fsort_key_timing\x18\x06 \x01(\x0b\x32\x10.cz.proto.Timing\x12\x30\n\x16permute_payload_timing\x18\x07 \x01(\x0b\x32\x10.cz.proto.Timing\x12*\n\x10spill_run_timing\x18\x08 \x01(\x0b\x32\x10.cz.proto.Timing\"\x10\n\x0eMergeSortStats\"\x0f\n\rUnionAllStats\"\r\n\x0bValuesStats\"8\n\x0b\x42ufferStats\x12)\n\x0bspill_stats\x18\x01 \x01(\x0b\x32\x14.cz.proto.SpillStats\"\r\n\x0bWindowStats\"\x14\n\x12PartialWindowStats\"\r\n\x0b\x45xpandStats\"\x12\n\x10LateralViewStats\"\x9d\x03\n\x11\x45xchangeSinkStats\x12\x17\n\x0fsent_byte_count\x18\x01 \x01(\x04\x12!\n\x19\x63ompress_input_byte_count\x18\x02 \x01(\x04\x12\x30\n\x16serialize_write_timing\x18\x03 \x01(\x0b\x32\x10.cz.proto.Timing\x12\x30\n\x16serialize_flush_timing\x18\x04 \x01(\x0b\x32\x10.cz.proto.Timing\x12)\n\x0f\x63ompress_timing\x18\x05 \x01(\x0b\x32\x10.cz.proto.Timing\x12/\n\x15\x61\x63quire_buffer_timing\x18\x06 \x01(\x0b\x32\x10.cz.proto.Timing\x12.\n\x14submit_buffer_timing\x18\x07 \x01(\x0b\x32\x10.cz.proto.Timing\x12&\n\x0c\x63lose_timing\x18\x08 \x01(\x0b\x32\x10.cz.proto.Timing\x12\x34\n\x1asubmit_buffer_async_timing\x18\t \x01(\x0b\x32\x10.cz.proto.Timing\"\xba\x02\n\x13\x45xchangeSourceStats\x12\x1b\n\x13received_byte_count\x18\x01 \x01(\x04\x12$\n\x1c\x64\x65\x63ompress_output_byte_count\x18\x02 \x01(\x04\x12,\n\x12\x64\x65serialize_timing\x18\x03 \x01(\x0b\x32\x10.cz.proto.Timing\x12+\n\x11\x64\x65\x63ompress_timing\x18\x04 \x01(\x0b\x32\x10.cz.proto.Timing\x12,\n\x12read_buffer_timing\x18\x05 \x01(\x0b\x32\x10.cz.proto.Timing\x12%\n\x0bsort_timing\x18\x06 \x01(\x0b\x32\x10.cz.proto.Timing\x12\x30\n\x12sorter_spill_stats\x18\x07 \x01(\x0b\x32\x14.cz.proto.SpillStats\"S\n\x05Table\x12\x0c\n\x04path\x18\x01 \x03(\t\x12\'\n\ntable_meta\x18\x02 \x01(\x0b\x32\x13.cz.proto.TableMeta\x12\x13\n\x0binstance_id\x18\x03 \x01(\x03\"k\n\x06Values\x12\x11\n\trow_count\x18\x01 \x01(\r\x12\x11\n\tcol_count\x18\x02 \x01(\r\x12(\n\x04\x64\x61ta\x18\x03 \x03(\x0b\x32\x1a.cz.proto.ScalarExpression\x12\x11\n\tbroadcast\x18\x04 \x01(\x08\"9\n\x0bSortKeyDesc\x12\n\n\x02id\x18\x01 \x01(\r\x12\x1e\n\x05order\x18\x02 \x01(\x0e\x32\x0f.cz.proto.Order\"\xf6\x03\n\tTableScan\x12\x1e\n\x05table\x18\x01 \x01(\x0b\x32\x0f.cz.proto.Table\x12\x1b\n\x13\x64\x61ta_source_info_id\x18\x02 \x01(\x05\x12\x0c\n\x04\x63ols\x18\x03 \x03(\x04\x12*\n\x06\x66ilter\x18\x04 \x01(\x0b\x32\x1a.cz.proto.ScalarExpression\x12\x31\n\rensuredFilter\x18\x05 \x01(\x0b\x32\x1a.cz.proto.ScalarExpression\x12-\n\x05props\x18\x06 \x03(\x0b\x32\x1e.cz.proto.TableScan.PropsEntry\x12\r\n\x05\x61lign\x18\x07 \x01(\x08\x12\x10\n\x08\x61lignDop\x18\x08 \x01(\x04\x12%\n\x06orders\x18\t \x03(\x0b\x32\x15.cz.proto.SortKeyDesc\x12\x12\n\nrange_keys\x18\n \x03(\r\x12\x1d\n\x15range_distribution_id\x18\x0b \x01(\r\x12\x36\n\x12tvr_table_property\x18\x0c \x01(\x0b\x32\x1a.cz.proto.TvrTableProperty\x12/\n\x0b\x66ilter4Meta\x18\r \x01(\x0b\x32\x1a.cz.proto.ScalarExpression\x1a,\n\nPropsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"?\n\x0eTableScanStats\x12-\n\x0binput_stats\x18\x01 \x01(\x0b\x32\x18.cz.proto.DataInputStats\"\x99\x01\n\x10TvrTableProperty\x12\x0c\n\x04\x66rom\x18\x01 \x01(\x03\x12\n\n\x02to\x18\x02 \x01(\x03\x12\x13\n\x0b\x63onsolidate\x18\x03 \x01(\x08\x12\x17\n\x0f\x66romMetaVersion\x18\x04 \x01(\x03\x12\x15\n\rtoMetaVersion\x18\x05 \x01(\x03\x12\x10\n\x08rowCount\x18\x06 \x01(\x03\x12\x14\n\x0c\x62\x61seRowCount\x18\x07 \x01(\x03\"\xc3\x01\n\x0bShuffleType\x12(\n\x04type\x18\x01 \x01(\x0e\x32\x1a.cz.proto.ShuffleType.Type\"\x89\x01\n\x04Type\x12\x08\n\x04HASH\x10\x00\x12\t\n\x05RANGE\x10\x01\x12\r\n\tBROADCAST\x10\x02\x12\n\n\x06SINGLE\x10\x03\x12\n\n\x06RANDOM\x10\x04\x12\r\n\tPAIR_WIZE\x10\x05\x12\x11\n\rADAPTIVE_HASH\x10\x06\x12\x12\n\x0e\x41\x44\x41PTIVE_RANGE\x10\x07\x12\x0f\n\x0bROUND_ROBIN\x10\x08\"\xd6\x02\n\tTableSink\x12\x1e\n\x05table\x18\x01 \x01(\x0b\x32\x0f.cz.proto.Table\x12\x11\n\toverwrite\x18\x02 \x01(\x08\x12\x1b\n\x13\x64\x61ta_source_info_id\x18\x03 \x01(\x05\x12!\n\x04keys\x18\x04 \x03(\x0b\x32\x13.cz.proto.Reference\x12\r\n\x05\x66lags\x18\x05 \x01(\r\x12+\n\x0epart_sort_keys\x18\x06 \x03(\x0b\x32\x13.cz.proto.Reference\x12\x14\n\x0cinput_fields\x18\x07 \x03(\x04\x12,\n\x0f\x66ile_slice_keys\x18\x08 \x03(\x0b\x32\x13.cz.proto.Reference\x12\x18\n\x10static_partition\x18\t \x01(\x08\x12/\n\x0bpart_values\x18\n \x01(\x0b\x32\x1a.cz.proto.VirtualValueInfo\x12\x0b\n\x03nop\x18\x0b \x01(\x08\"\xfb\x01\n\x0cShuffleWrite\x12*\n\x0bshuffleType\x18\x01 \x01(\x0b\x32\x15.cz.proto.ShuffleType\x12!\n\x04keys\x18\x02 \x03(\x0b\x32\x13.cz.proto.Reference\x12%\n\x06orders\x18\x03 \x03(\x0b\x32\x15.cz.proto.OrderByDesc\x12\r\n\x05limit\x18\x04 \x01(\r\x12\x18\n\x10\x66unction_version\x18\x05 \x01(\r\x12-\n\x0b\x62ucket_type\x18\x06 \x01(\x0e\x32\x18.cz.proto.HashBucketType\x12\x1d\n\x15range_distribution_id\x18\x07 \x01(\r\"\xbe\x01\n\x0bShuffleRead\x12%\n\x06orders\x18\x01 \x03(\x0b\x32\x15.cz.proto.OrderByDesc\x12\r\n\x05limit\x18\x02 \x01(\r\x12\x0e\n\x06offset\x18\x03 \x01(\r\x12*\n\x0bshuffleType\x18\x04 \x01(\x0b\x32\x15.cz.proto.ShuffleType\x12\x16\n\x0emulti_accessed\x18\x05 \x01(\x08\x12\x11\n\tpre_start\x18\x06 \x01(\x08\x12\x12\n\nmerge_sort\x18\x07 \x01(\x08\"\xbe\x01\n\rLocalExchange\x12*\n\x0bshuffleType\x18\x01 \x01(\x0b\x32\x15.cz.proto.ShuffleType\x12!\n\x04keys\x18\x02 \x03(\x0b\x32\x13.cz.proto.Reference\x12%\n\x06orders\x18\x03 \x03(\x0b\x32\x15.cz.proto.OrderByDesc\x12\r\n\x05limit\x18\x04 \x01(\r\x12\x0e\n\x06offset\x18\x05 \x01(\r\x12\x18\n\x10\x66unction_version\x18\x06 \x01(\r\"Q\n\tLocalSort\x12%\n\x06orders\x18\x01 \x03(\x0b\x32\x15.cz.proto.OrderByDesc\x12\r\n\x05limit\x18\x02 \x01(\x04\x12\x0e\n\x06offset\x18\x03 \x01(\x04\"\xbe\x01\n\x0bLogicalSort\x12!\n\x04keys\x18\x01 \x03(\x0b\x32\x13.cz.proto.Reference\x12%\n\x06orders\x18\x02 \x03(\x0b\x32\x15.cz.proto.OrderByDesc\x12)\n\x05limit\x18\x03 \x01(\x0b\x32\x1a.cz.proto.ScalarExpression\x12*\n\x06offset\x18\x04 \x01(\x0b\x32\x1a.cz.proto.ScalarExpression\x12\x0e\n\x06global\x18\x05 \x01(\x08\"W\n\x0bSetOperator\x12!\n\x04type\x18\x01 \x01(\x0e\x32\x13.cz.proto.SetOpType\x12\x0b\n\x03\x61ll\x18\x02 \x01(\x08\x12\x18\n\x10input_references\x18\x03 \x03(\x04\"\xdc\x01\n\x0e\x44\x61taInputStats\x12\x1c\n\x14raw_input_byte_count\x18\x01 \x01(\x04\x12\x11\n\trow_count\x18\x02 \x01(\x04\x12:\n\x10\x66ile_input_stats\x18\x03 \x01(\x0b\x32\x1e.cz.proto.FileRangesInputStatsH\x00\x12\x35\n\x11\x66ile_format_stats\x18\x04 \x01(\x0b\x32\x18.cz.proto.FileInputStatsH\x00\x12\x17\n\x0ftime_elapsed_us\x18\x05 \x01(\x04\x42\r\n\x0binput_stats\"J\n\x14\x46ileRangesInputStats\x12\x32\n\x10\x66ile_input_stats\x18\x01 \x03(\x0b\x32\x18.cz.proto.DataInputStats\"\x9f\x05\n\x0e\x46ileInputStats\x12-\n\x0b\x66ormat_type\x18\x01 \x01(\x0e\x32\x18.cz.proto.FileFormatType\x12\"\n\x05range\x18\x02 \x01(\x0b\x32\x13.cz.proto.FileRange\x12\x34\n\x10text_input_stats\x18\x03 \x01(\x0b\x32\x18.cz.proto.TextInputStatsH\x00\x12:\n\x13parquet_input_stats\x18\x04 \x01(\x0b\x32\x1b.cz.proto.ParquetInputStatsH\x00\x12=\n\x12memory_input_stats\x18\x05 \x01(\x0b\x32\x1f.cz.proto.MemoryTableInputStatsH\x00\x12\x32\n\x0forc_input_stats\x18\x08 \x01(\x0b\x32\x17.cz.proto.OrcInputStatsH\x00\x12\x36\n\x11\x64ummy_input_stats\x18\t \x01(\x0b\x32\x19.cz.proto.DummyInputStatsH\x00\x12\x32\n\x0f\x63sv_input_stats\x18\n \x01(\x0b\x32\x17.cz.proto.CSVInputStatsH\x00\x12\x34\n\x10\x61vro_input_stats\x18\x0b \x01(\x0b\x32\x18.cz.proto.AvroInputStatsH\x00\x12\x36\n\x11\x61rrow_input_stats\x18\x0c \x01(\x0b\x32\x19.cz.proto.ArrowInputStatsH\x00\x12,\n\x08io_stats\x18\x06 \x01(\x0b\x32\x1a.cz.proto.FileIOInputStats\x12\x32\n\x10\x64\x65lta_file_stats\x18\x07 \x03(\x0b\x32\x18.cz.proto.DataInputStatsB\x19\n\x17\x66ile_format_input_stats\"\xb9\x01\n\x10\x46ileIOInputStats\x12\x12\n\nread_count\x18\x01 \x01(\x04\x12\x12\n\nread_bytes\x18\x02 \x01(\x04\x12\x17\n\x0ftime_elapsed_us\x18\x03 \x01(\x04\x12/\n\x0eprefetch_stats\x18\x04 \x01(\x0b\x32\x17.cz.proto.PrefetchStats\x12\x33\n\x0binput_stats\x18\x05 \x01(\x0b\x32\x1e.cz.proto.FileInputStreamStats\",\n\x11\x46ileIOOutputStats\x12\x17\n\x0ftime_elapsed_us\x18\x01 \x01(\x04\"\xc2\x01\n\rPrefetchStats\x12\x13\n\x0b\x64river_type\x18\x08 \x01(\t\x12\x12\n\nread_count\x18\x01 \x01(\x04\x12\x12\n\nread_bytes\x18\x02 \x01(\x04\x12\x16\n\x0eread_hit_cache\x18\x03 \x01(\x04\x12\x1c\n\x14read_time_elapsed_us\x18\x04 \x01(\x04\x12\x10\n\x08io_count\x18\x05 \x01(\x04\x12\x10\n\x08io_bytes\x18\x06 \x01(\x04\x12\x1a\n\x12io_time_elapsed_us\x18\x07 \x01(\x04\"\xb3\x01\n\x14\x46ileInputStreamStats\x12\x32\n\x10\x66ile_system_type\x18\x01 \x01(\x0e\x32\x18.cz.proto.FileSystemType\x12L\n\x1d\x63\x61\x63he_file_input_stream_stats\x18\x04 \x01(\x0b\x32#.cz.proto.CacheFileInputStreamStatsH\x00\x42\x19\n\x17\x66ile_input_stream_stats\"\x83\x02\n\x19\x43\x61\x63heFileInputStreamStats\x12\x11\n\tcache_hit\x18\x01 \x01(\x08\x12!\n\x19short_circuit_stream_type\x18\x02 \x01(\t\x12\x14\n\x0csegment_mode\x18\x03 \x01(\x08\x12 \n\x18non_read_time_elapsed_us\x18\x04 \x01(\x04\x12\x16\n\x0erpc_read_bytes\x18\x05 \x01(\x04\x12 \n\x18rpc_read_time_elapsed_us\x18\x06 \x01(\x04\x12\x19\n\x11\x64irect_read_bytes\x18\x07 \x01(\x04\x12#\n\x1b\x64irect_read_time_elapsed_us\x18\x08 \x01(\x04\"V\n\x0eTextInputStats\x12\"\n\x1amissing_field_warned_count\x18\x01 \x01(\x04\x12 \n\x18\x65xtra_field_warned_count\x18\x02 \x01(\x04\",\n\x15MemoryTableInputStats\x12\x13\n\x0b\x62\x61tch_count\x18\x01 \x01(\x04\"\x8b\x02\n\x11ParquetInputStats\x12\x13\n\x0b\x62\x61tch_count\x18\x01 \x01(\x04\x12 \n\x18\x64\x65\x63ompression_latency_ns\x18\x02 \x01(\x04\x12\"\n\x1alevels_decoding_latency_ns\x18\x03 \x01(\x04\x12\x1f\n\x17\x64\x61ta_loading_latency_ns\x18\x04 \x01(\x04\x12 \n\x18ppd_inclusive_latency_ns\x18\x05 \x01(\x04\x12#\n\x1breader_inclusive_latency_ns\x18\x06 \x01(\x04\x12\x1b\n\x13requested_row_count\x18\x07 \x01(\x04\x12\x16\n\x0eread_row_count\x18\x08 \x01(\x04\"$\n\rOrcInputStats\x12\x13\n\x0b\x62\x61tch_count\x18\x01 \x01(\x04\"\x0f\n\rCSVInputStats\"&\n\x0f\x44ummyInputStats\x12\x13\n\x0b\x62\x61tch_count\x18\x01 \x01(\x04\"\x10\n\x0e\x41vroInputStats\"\x11\n\x0f\x41rrowInputStats\"\xd3\x01\n\x0f\x44\x61taOutputStats\x12\x1d\n\x15raw_output_byte_count\x18\x01 \x01(\x04\x12\x11\n\trow_count\x18\x02 \x01(\x04\x12\x36\n\x11\x66ile_output_stats\x18\x03 \x01(\x0b\x32\x19.cz.proto.FileOutputStatsH\x00\x12G\n\x1amultiple_file_output_stats\x18\x04 \x01(\x0b\x32!.cz.proto.MultipleFileOutputStatsH\x00\x42\r\n\x0boutputStats\"\xdd\x03\n\x0f\x46ileOutputStats\x12.\n\x0e\x66ile_meta_data\x18\x01 \x01(\x0b\x32\x16.cz.proto.FileMetaData\x12\x36\n\x11text_output_stats\x18\x02 \x01(\x0b\x32\x19.cz.proto.TextOutputStatsH\x00\x12<\n\x14parquet_output_stats\x18\x03 \x01(\x0b\x32\x1c.cz.proto.ParquetOutputStatsH\x00\x12\x34\n\x10orc_output_stats\x18\x06 \x01(\x0b\x32\x18.cz.proto.OrcOutputStatsH\x00\x12\x36\n\x11\x61vro_output_stats\x18\x07 \x01(\x0b\x32\x19.cz.proto.AvroOutputStatsH\x00\x12\x38\n\x12\x61rrow_output_stats\x18\x08 \x01(\x0b\x32\x1a.cz.proto.ArrowOutputStatsH\x00\x12-\n\x08io_stats\x18\x04 \x01(\x0b\x32\x1b.cz.proto.FileIOOutputStats\x12\x31\n\x11\x64\x65lete_file_metas\x18\x05 \x03(\x0b\x32\x16.cz.proto.FileMetaDataB\x1a\n\x18\x66ile_format_output_stats\"O\n\x17MultipleFileOutputStats\x12\x34\n\x11\x66ile_output_stats\x18\x01 \x03(\x0b\x32\x19.cz.proto.DataOutputStats\"\x11\n\x0fTextOutputStats\"c\n\x12ParquetOutputStats\x12\x1a\n\x12\x61rrow_casting_time\x18\x01 \x01(\x04\x12\x1a\n\x12page_compress_time\x18\x02 \x01(\x04\x12\x15\n\rencoding_time\x18\x03 \x01(\x04\"\x10\n\x0eOrcOutputStats\"\x11\n\x0f\x41vroOutputStats\"\x12\n\x10\x41rrowOutputStats\"A\n\x0eTableSinkStats\x12/\n\x0coutput_stats\x18\x01 \x01(\x0b\x32\x19.cz.proto.DataOutputStats\"_\n\nSpillStats\x12\x17\n\x0f\x63ompressed_size\x18\x01 \x01(\x04\x12\x10\n\x08raw_size\x18\x02 \x01(\x04\x12\x13\n\x0bspill_count\x18\x03 \x01(\x04\x12\x11\n\trow_count\x18\x04 \x01(\x04*N\n\x08\x41ggStage\x12\r\n\tDUPLICATE\x10\x00\x12\x0c\n\x08PARTIAL1\x10\x01\x12\x0c\n\x08PARTIAL2\x10\x02\x12\t\n\x05\x46INAL\x10\x03\x12\x0c\n\x08\x43OMPLETE\x10\x04*R\n\x08JoinType\x12\t\n\x05INNER\x10\x00\x12\x08\n\x04LEFT\x10\x01\x12\t\n\x05RIGHT\x10\x02\x12\x08\n\x04\x46ULL\x10\x03\x12\r\n\tLEFT_SEMI\x10\x04\x12\r\n\tLEFT_ANTI\x10\x05*R\n\x11\x44ynamicFilterType\x12\x0b\n\x07\x44\x46_NONE\x10\x00\x12\r\n\tDF_GLOBAL\x10\x01\x12\x10\n\x0c\x44\x46_BROADCAST\x10\x02\x12\x0f\n\x0b\x44\x46_SHUFFLED\x10\x03*@\n\x08LazyEval\x12\x0c\n\x08NOT_LAZY\x10\x00\x12\x15\n\x11LAZY_IN_CONDITION\x10\x01\x12\x0f\n\x0b\x41LWAYS_LAZY\x10\x02*1\n\tSetOpType\x12\t\n\x05UNION\x10\x00\x12\r\n\tINTERSECT\x10\x01\x12\n\n\x06\x45XCEPT\x10\x02\x42\x11\x42\rOperatorProtoP\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'operator_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'B\rOperatorProtoP\001'
  _TABLESCAN_PROPSENTRY._options = None
  _TABLESCAN_PROPSENTRY._serialized_options = b'8\001'
  _AGGSTAGE._serialized_start=15373
  _AGGSTAGE._serialized_end=15451
  _JOINTYPE._serialized_start=15453
  _JOINTYPE._serialized_end=15535
  _DYNAMICFILTERTYPE._serialized_start=15537
  _DYNAMICFILTERTYPE._serialized_end=15619
  _LAZYEVAL._serialized_start=15621
  _LAZYEVAL._serialized_end=15685
  _SETOPTYPE._serialized_start=15687
  _SETOPTYPE._serialized_end=15736
  _COLUMNMAPPING._serialized_start=211
  _COLUMNMAPPING._serialized_end=261
  _OPERATOR._serialized_start=264
  _OPERATOR._serialized_end=1684
  _AGGREGATECALL._serialized_start=1687
  _AGGREGATECALL._serialized_end=2025
  _LOGICALAGGREGATE._serialized_start=2027
  _LOGICALAGGREGATE._serialized_end=2130
  _HASHAGGREGATE._serialized_start=2132
  _HASHAGGREGATE._serialized_end=2229
  _SORTEDAGGREGATE._serialized_start=2232
  _SORTEDAGGREGATE._serialized_end=2370
  _AGGREGATEPHASE._serialized_start=2372
  _AGGREGATEPHASE._serialized_end=2470
  _DYNAMICFILTERINFO._serialized_start=2473
  _DYNAMICFILTERINFO._serialized_end=2643
  _JOINHINTINFO._serialized_start=2645
  _JOINHINTINFO._serialized_end=2686
  _TREEJOIN._serialized_start=2688
  _TREEJOIN._serialized_end=2742
  _TREEJOINLEAF._serialized_start=2744
  _TREEJOINLEAF._serialized_end=2803
  _LOGICALJOIN._serialized_start=2806
  _LOGICALJOIN._serialized_end=3021
  _SORTMERGEJOIN._serialized_start=3024
  _SORTMERGEJOIN._serialized_end=3162
  _HASHJOIN._serialized_start=3164
  _HASHJOIN._serialized_end=3257
  _TIMING._serialized_start=3259
  _TIMING._serialized_end=3306
  _OPERATORSTATS._serialized_start=3309
  _OPERATORSTATS._serialized_end=4688
  _ORDERBYDESC._serialized_start=4690
  _ORDERBYDESC._serialized_end=4775
  _MERGESORT._serialized_start=4777
  _MERGESORT._serialized_end=4853
  _UNIONALL._serialized_start=4855
  _UNIONALL._serialized_end=4891
  _BUFFER._serialized_start=4893
  _BUFFER._serialized_end=4917
  _PARTIALWINDOWFILTER._serialized_start=4919
  _PARTIALWINDOWFILTER._serialized_end=5037
  _WINDOW._serialized_start=5039
  _WINDOW._serialized_end=5112
  _WINDOWGROUP._serialized_start=5114
  _WINDOWGROUP._serialized_end=5204
  _WINDOWCALL._serialized_start=5206
  _WINDOWCALL._serialized_end=5324
  _WINDOWSPEC._serialized_start=5327
  _WINDOWSPEC._serialized_end=5613
  _WINDOWSPEC_BOUNDARYTYPE._serialized_start=5567
  _WINDOWSPEC_BOUNDARYTYPE._serialized_end=5613
  _WINDOWBOUNDARY._serialized_start=5615
  _WINDOWBOUNDARY._serialized_end=5705
  _LATERALVIEW._serialized_start=5707
  _LATERALVIEW._serialized_end=5794
  _TABLEFUNCTIONCALL._serialized_start=5796
  _TABLEFUNCTIONCALL._serialized_end=5897
  _SPOOL._serialized_start=5899
  _SPOOL._serialized_end=5924
  _CALC._serialized_start=5927
  _CALC._serialized_end=6178
  _LOGICALCALC._serialized_start=6181
  _LOGICALCALC._serialized_end=6373
  _EXPAND._serialized_start=6375
  _EXPAND._serialized_end=6432
  _GROUPINGKEYSET._serialized_start=6434
  _GROUPINGKEYSET._serialized_end=6485
  _GROUPING._serialized_start=6488
  _GROUPING._serialized_end=6722
  _CALCSTATS._serialized_start=6724
  _CALCSTATS._serialized_end=6735
  _HASHTABLESTATS._serialized_start=6738
  _HASHTABLESTATS._serialized_end=6880
  _HASHJOINSTATS._serialized_start=6883
  _HASHJOINSTATS._serialized_end=7504
  _MERGEJOINSTATS._serialized_start=7506
  _MERGEJOINSTATS._serialized_end=7522
  _HASHAGGREGATESTATS._serialized_start=7525
  _HASHAGGREGATESTATS._serialized_end=7884
  _MERGEAGGREGATESTATS._serialized_start=7887
  _MERGEAGGREGATESTATS._serialized_end=8045
  _LOCALSORTSTATS._serialized_start=8048
  _LOCALSORTSTATS._serialized_end=8431
  _MERGESORTSTATS._serialized_start=8433
  _MERGESORTSTATS._serialized_end=8449
  _UNIONALLSTATS._serialized_start=8451
  _UNIONALLSTATS._serialized_end=8466
  _VALUESSTATS._serialized_start=8468
  _VALUESSTATS._serialized_end=8481
  _BUFFERSTATS._serialized_start=8483
  _BUFFERSTATS._serialized_end=8539
  _WINDOWSTATS._serialized_start=8541
  _WINDOWSTATS._serialized_end=8554
  _PARTIALWINDOWSTATS._serialized_start=8556
  _PARTIALWINDOWSTATS._serialized_end=8576
  _EXPANDSTATS._serialized_start=8578
  _EXPANDSTATS._serialized_end=8591
  _LATERALVIEWSTATS._serialized_start=8593
  _LATERALVIEWSTATS._serialized_end=8611
  _EXCHANGESINKSTATS._serialized_start=8614
  _EXCHANGESINKSTATS._serialized_end=9027
  _EXCHANGESOURCESTATS._serialized_start=9030
  _EXCHANGESOURCESTATS._serialized_end=9344
  _TABLE._serialized_start=9346
  _TABLE._serialized_end=9429
  _VALUES._serialized_start=9431
  _VALUES._serialized_end=9538
  _SORTKEYDESC._serialized_start=9540
  _SORTKEYDESC._serialized_end=9597
  _TABLESCAN._serialized_start=9600
  _TABLESCAN._serialized_end=10102
  _TABLESCAN_PROPSENTRY._serialized_start=10058
  _TABLESCAN_PROPSENTRY._serialized_end=10102
  _TABLESCANSTATS._serialized_start=10104
  _TABLESCANSTATS._serialized_end=10167
  _TVRTABLEPROPERTY._serialized_start=10170
  _TVRTABLEPROPERTY._serialized_end=10323
  _SHUFFLETYPE._serialized_start=10326
  _SHUFFLETYPE._serialized_end=10521
  _SHUFFLETYPE_TYPE._serialized_start=10384
  _SHUFFLETYPE_TYPE._serialized_end=10521
  _TABLESINK._serialized_start=10524
  _TABLESINK._serialized_end=10866
  _SHUFFLEWRITE._serialized_start=10869
  _SHUFFLEWRITE._serialized_end=11120
  _SHUFFLEREAD._serialized_start=11123
  _SHUFFLEREAD._serialized_end=11313
  _LOCALEXCHANGE._serialized_start=11316
  _LOCALEXCHANGE._serialized_end=11506
  _LOCALSORT._serialized_start=11508
  _LOCALSORT._serialized_end=11589
  _LOGICALSORT._serialized_start=11592
  _LOGICALSORT._serialized_end=11782
  _SETOPERATOR._serialized_start=11784
  _SETOPERATOR._serialized_end=11871
  _DATAINPUTSTATS._serialized_start=11874
  _DATAINPUTSTATS._serialized_end=12094
  _FILERANGESINPUTSTATS._serialized_start=12096
  _FILERANGESINPUTSTATS._serialized_end=12170
  _FILEINPUTSTATS._serialized_start=12173
  _FILEINPUTSTATS._serialized_end=12844
  _FILEIOINPUTSTATS._serialized_start=12847
  _FILEIOINPUTSTATS._serialized_end=13032
  _FILEIOOUTPUTSTATS._serialized_start=13034
  _FILEIOOUTPUTSTATS._serialized_end=13078
  _PREFETCHSTATS._serialized_start=13081
  _PREFETCHSTATS._serialized_end=13275
  _FILEINPUTSTREAMSTATS._serialized_start=13278
  _FILEINPUTSTREAMSTATS._serialized_end=13457
  _CACHEFILEINPUTSTREAMSTATS._serialized_start=13460
  _CACHEFILEINPUTSTREAMSTATS._serialized_end=13719
  _TEXTINPUTSTATS._serialized_start=13721
  _TEXTINPUTSTATS._serialized_end=13807
  _MEMORYTABLEINPUTSTATS._serialized_start=13809
  _MEMORYTABLEINPUTSTATS._serialized_end=13853
  _PARQUETINPUTSTATS._serialized_start=13856
  _PARQUETINPUTSTATS._serialized_end=14123
  _ORCINPUTSTATS._serialized_start=14125
  _ORCINPUTSTATS._serialized_end=14161
  _CSVINPUTSTATS._serialized_start=14163
  _CSVINPUTSTATS._serialized_end=14178
  _DUMMYINPUTSTATS._serialized_start=14180
  _DUMMYINPUTSTATS._serialized_end=14218
  _AVROINPUTSTATS._serialized_start=14220
  _AVROINPUTSTATS._serialized_end=14236
  _ARROWINPUTSTATS._serialized_start=14238
  _ARROWINPUTSTATS._serialized_end=14255
  _DATAOUTPUTSTATS._serialized_start=14258
  _DATAOUTPUTSTATS._serialized_end=14469
  _FILEOUTPUTSTATS._serialized_start=14472
  _FILEOUTPUTSTATS._serialized_end=14949
  _MULTIPLEFILEOUTPUTSTATS._serialized_start=14951
  _MULTIPLEFILEOUTPUTSTATS._serialized_end=15030
  _TEXTOUTPUTSTATS._serialized_start=15032
  _TEXTOUTPUTSTATS._serialized_end=15049
  _PARQUETOUTPUTSTATS._serialized_start=15051
  _PARQUETOUTPUTSTATS._serialized_end=15150
  _ORCOUTPUTSTATS._serialized_start=15152
  _ORCOUTPUTSTATS._serialized_end=15168
  _AVROOUTPUTSTATS._serialized_start=15170
  _AVROOUTPUTSTATS._serialized_end=15187
  _ARROWOUTPUTSTATS._serialized_start=15189
  _ARROWOUTPUTSTATS._serialized_end=15207
  _TABLESINKSTATS._serialized_start=15209
  _TABLESINKSTATS._serialized_end=15274
  _SPILLSTATS._serialized_start=15276
  _SPILLSTATS._serialized_end=15371
# @@protoc_insertion_point(module_scope)
