# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: data_type.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0f\x64\x61ta_type.proto\x12\x08\x63z.proto\"\x1e\n\x0c\x43harTypeInfo\x12\x0e\n\x06length\x18\x01 \x01(\x04\"!\n\x0fVarCharTypeInfo\x12\x0e\n\x06length\x18\x01 \x01(\x04\"3\n\x0f\x44\x65\x63imalTypeInfo\x12\x11\n\tprecision\x18\x01 \x01(\x04\x12\r\n\x05scale\x18\x02 \x01(\x04\"\x8b\x01\n\x13IntervalDayTimeInfo\x12$\n\x04\x66rom\x18\x01 \x01(\x0e\x32\x16.cz.proto.IntervalUnit\x12\"\n\x02to\x18\x02 \x01(\x0e\x32\x16.cz.proto.IntervalUnit\x12*\n\tprecision\x18\x03 \x01(\x0e\x32\x17.cz.proto.TimestampUnit\"a\n\x15IntervalYearMonthInfo\x12$\n\x04\x66rom\x18\x01 \x01(\x0e\x32\x16.cz.proto.IntervalUnit\x12\"\n\x02to\x18\x02 \x01(\x0e\x32\x16.cz.proto.IntervalUnit\"8\n\rArrayTypeInfo\x12\'\n\x0b\x65lementType\x18\x01 \x01(\x0b\x32\x12.cz.proto.DataType\"Y\n\x0bMapTypeInfo\x12#\n\x07keyType\x18\x01 \x01(\x0b\x32\x12.cz.proto.DataType\x12%\n\tvalueType\x18\x02 \x01(\x0b\x32\x12.cz.proto.DataType\"y\n\x0eStructTypeInfo\x12.\n\x06\x66ields\x18\x01 \x03(\x0b\x32\x1e.cz.proto.StructTypeInfo.Field\x1a\x37\n\x05\x46ield\x12\x0c\n\x04name\x18\x01 \x01(\t\x12 \n\x04type\x18\x02 \x01(\x0b\x32\x12.cz.proto.DataType\"]\n\x10\x46unctionTypeInfo\x12 \n\x04\x61rgs\x18\x01 \x03(\x0b\x32\x12.cz.proto.DataType\x12\'\n\x0breturn_type\x18\x02 \x01(\x0b\x32\x12.cz.proto.DataType\"8\n\rTimestampInfo\x12\'\n\x06tsUnit\x18\x01 \x01(\x0e\x32\x17.cz.proto.TimestampUnit\"\x82\x05\n\x08\x44\x61taType\x12,\n\x08\x63\x61tegory\x18\x01 \x01(\x0e\x32\x1a.cz.proto.DataTypeCategory\x12\x10\n\x08nullable\x18\x02 \x01(\x08\x12\x10\n\x08\x66ield_id\x18\x0b \x01(\r\x12.\n\x0c\x63harTypeInfo\x18\x03 \x01(\x0b\x32\x16.cz.proto.CharTypeInfoH\x00\x12\x34\n\x0fvarCharTypeInfo\x18\x04 \x01(\x0b\x32\x19.cz.proto.VarCharTypeInfoH\x00\x12\x34\n\x0f\x64\x65\x63imalTypeInfo\x18\x05 \x01(\x0b\x32\x19.cz.proto.DecimalTypeInfoH\x00\x12\x30\n\rarrayTypeInfo\x18\x06 \x01(\x0b\x32\x17.cz.proto.ArrayTypeInfoH\x00\x12,\n\x0bmapTypeInfo\x18\x07 \x01(\x0b\x32\x15.cz.proto.MapTypeInfoH\x00\x12\x32\n\x0estructTypeInfo\x18\x08 \x01(\x0b\x32\x18.cz.proto.StructTypeInfoH\x00\x12?\n\x16interval_day_time_info\x18\t \x01(\x0b\x32\x1d.cz.proto.IntervalDayTimeInfoH\x00\x12\x43\n\x18interval_year_month_info\x18\n \x01(\x0b\x32\x1f.cz.proto.IntervalYearMonthInfoH\x00\x12\x31\n\x0etimestamp_info\x18\x0c \x01(\x0b\x32\x17.cz.proto.TimestampInfoH\x00\x12\x33\n\rfunction_info\x18\r \x01(\x0b\x32\x1a.cz.proto.FunctionTypeInfoH\x00\x42\x06\n\x04info*\xc1\x02\n\x10\x44\x61taTypeCategory\x12\x08\n\x04NONE\x10\x00\x12\x08\n\x04INT8\x10\x01\x12\t\n\x05INT16\x10\x02\x12\t\n\x05INT32\x10\x03\x12\t\n\x05INT64\x10\x04\x12\x0b\n\x07\x46LOAT32\x10\x05\x12\x0b\n\x07\x46LOAT64\x10\x06\x12\x0b\n\x07\x44\x45\x43IMAL\x10\x07\x12\x0b\n\x07\x42OOLEAN\x10\x08\x12\x08\n\x04\x43HAR\x10\t\x12\x0b\n\x07VARCHAR\x10\n\x12\n\n\x06STRING\x10\x0b\x12\n\n\x06\x42INARY\x10\x0c\x12\x08\n\x04\x44\x41TE\x10\r\x12\x11\n\rTIMESTAMP_LTZ\x10\x0e\x12\x17\n\x13INTERVAL_YEAR_MONTH\x10\x0f\x12\x15\n\x11INTERVAL_DAY_TIME\x10\x10\x12\n\n\x06\x42ITMAP\x10\x32\x12\t\n\x05\x41RRAY\x10\x64\x12\x07\n\x03MAP\x10\x65\x12\n\n\x06STRUCT\x10\x66\x12\x11\n\rFUNCTION_TYPE\x10g\x12\t\n\x04VOID\x10\xc8\x01*f\n\x0cIntervalUnit\x12\x16\n\x12NONE_INTERVAL_UNIT\x10\x00\x12\x08\n\x04YEAR\x10\x01\x12\t\n\x05MONTH\x10\x02\x12\x07\n\x03\x44\x41Y\x10\x03\x12\x08\n\x04HOUR\x10\x04\x12\n\n\x06MINUTE\x10\x05\x12\n\n\x06SECOND\x10\x06*Q\n\rTimestampUnit\x12\x0b\n\x07SECONDS\x10\x00\x12\x10\n\x0cMILLISECONDS\x10\x03\x12\x10\n\x0cMICROSECONDS\x10\x06\x12\x0f\n\x0bNANOSECONDS\x10\tB\x0c\n\x08\x63z.protoP\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'data_type_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\010cz.protoP\001'
  _DATATYPECATEGORY._serialized_start=1461
  _DATATYPECATEGORY._serialized_end=1782
  _INTERVALUNIT._serialized_start=1784
  _INTERVALUNIT._serialized_end=1886
  _TIMESTAMPUNIT._serialized_start=1888
  _TIMESTAMPUNIT._serialized_end=1969
  _CHARTYPEINFO._serialized_start=29
  _CHARTYPEINFO._serialized_end=59
  _VARCHARTYPEINFO._serialized_start=61
  _VARCHARTYPEINFO._serialized_end=94
  _DECIMALTYPEINFO._serialized_start=96
  _DECIMALTYPEINFO._serialized_end=147
  _INTERVALDAYTIMEINFO._serialized_start=150
  _INTERVALDAYTIMEINFO._serialized_end=289
  _INTERVALYEARMONTHINFO._serialized_start=291
  _INTERVALYEARMONTHINFO._serialized_end=388
  _ARRAYTYPEINFO._serialized_start=390
  _ARRAYTYPEINFO._serialized_end=446
  _MAPTYPEINFO._serialized_start=448
  _MAPTYPEINFO._serialized_end=537
  _STRUCTTYPEINFO._serialized_start=539
  _STRUCTTYPEINFO._serialized_end=660
  _STRUCTTYPEINFO_FIELD._serialized_start=605
  _STRUCTTYPEINFO_FIELD._serialized_end=660
  _FUNCTIONTYPEINFO._serialized_start=662
  _FUNCTIONTYPEINFO._serialized_end=755
  _TIMESTAMPINFO._serialized_start=757
  _TIMESTAMPINFO._serialized_end=813
  _DATATYPE._serialized_start=816
  _DATATYPE._serialized_end=1458
# @@protoc_insertion_point(module_scope)
